/*
//
//       Elvees Performance Platform
//           image processing
//
*/

#pragma once

#include "eppdefs.h"

#ifdef __cplusplus
extern "C" {
#endif


/*
//  Name:       eppi_GetLibraryVersion
//  Purpose:    gets the version of the library
//  Returns:    structure containing information about the current version of the EPPI library
//  Parameters: None
*/
EPPAPI( const epp_LibraryVersion*, eppi_GetLibraryVersion, (void) )


/*
//  Name:        eppi_Set
//  Purpose:     Sets image data
//  Context:
//  Returns:     epp_Status
//    epp_StsOK  OK
//  Parameters:
//    val        Value(s) to set
//    pDst       Pointer to the destination image (multichannel or planes)
//    dstStep    Step through the destination image(s)
//    width      The width of images.
//    height     The height of images.
//  Notes:
*/
EPPAPI(epp_Status, eppi_Set_u8_C1, (epp_u8 val, epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height))
EPPAPI(epp_Status, eppi_Set_u8_C3, (const epp_u8 val[3], epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height))
EPPAPI(epp_Status, eppi_Set_u8_C4, (const epp_u8 val[4], epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height))
EPPAPI(epp_Status, eppi_Set_u8_C1C3, (epp_u8 val, epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height))
EPPAPI(epp_Status, eppi_Set_u8_C1C4, (epp_u8 val, epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height))


/*
//  Name:        eppi_Copy
//  Purpose:     Copies image data
//  Context:
//  Returns:     epp_Status
//    epp_StsOK  OK
//  Parameters:
//    pSrc       Pointer to the source image (multichannel or planes)
//    srcStep    Step through the source image(s)
//    pDst       Pointer to the destination image (multichannel or planes)
//    dstStep    Step through the destination image(s)
//    width      The width of images.
//    height     The height of images.
//  Notes:
*/
EPPAPI(epp_Status, eppi_Copy_u8_C1, (const epp_u8* pSrc, epp_s32 srcStep, epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height))
EPPAPI(epp_Status, eppi_Copy_u8_C1C3, (const epp_u8* pSrc, epp_s32 srcStep, epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height))
EPPAPI(epp_Status, eppi_Copy_u8_C3C1, (const epp_u8* pSrc, epp_s32 srcStep, epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height))
EPPAPI(epp_Status, eppi_Copy_u8_C3P3, (const epp_u8* pSrc, epp_s32 srcStep, epp_u8* const pDst[3], const epp_s32 dstStep[3], epp_size width, epp_size height))
EPPAPI(epp_Status, eppi_Copy_u8_P3C3, (const epp_u8* const pSrc[3], const epp_s32 srcStep[3], epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height))
EPPINL(epp_Status, eppi_Copy_u8_C3, (const epp_u8* pSrc, epp_s32 srcStep, epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height))
{
    return eppi_Copy_u8_C1(pSrc, srcStep, pDst, dstStep, width * 3, height);
}
EPPINL(epp_Status, eppi_Copy_u8_C4, (const epp_u8* pSrc, epp_s32 srcStep, epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height))
{
    return eppi_Copy_u8_C1(pSrc, srcStep, pDst, dstStep, width * 4, height);
}


/*
//  Name:        eppi_Duplicate_u8_C1C3
//  Purpose:     Duplicates C1 image in all channels of C3 image
//  Context:
//  Returns:     epp_Status
//    epp_StsOK  OK
//  Parameters:
//    pSrc       Pointer to the source image
//    srcStep    Step through the source image
//    pDst       Pointer to the destination image(s)
//    dstStep    Step through the destination image(s)
//    width      The width of images.
//    height     The height of images.
//  Notes:
*/
EPPAPI(epp_Status, eppi_Duplicate_u8_C1C3, (const epp_u8* pSrc, epp_s32 srcStep, epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height))
EPPAPI(epp_Status, eppi_Duplicate_u8_C1P3, (const epp_u8* pSrc, epp_s32 srcStep, epp_u8* const pDst[3], const epp_s32 dstStep[3], epp_size width, epp_size height))


/*
//  Name:        eppi_ColorConversion
//  Purpose:     Prforms Color conversion
//  Context:
//  Returns:     epp_Status
//    epp_StsOK  OK
//  Parameters:
//    pSrc       Pointer to the source image (multichannel or planes)
//    srcStep    Step through the source image(s)
//    pDst       Pointer to the destination image (multichannel or planes)
//    dstStep    Step through the destination image(s)
//    width      The width of images.
//    height     The height of images.
//  Notes:
*/
EPPAPI(epp_Status, eppi_YPbPr444_RGB_BT601_u8_P3C3, (const epp_u8* const pSrc[3], const epp_s32 srcStep[3], epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height))
EPPAPI(epp_Status, eppi_YPbPr422_RGB_BT601_u8_P3C3, (const epp_u8* const pSrc[3], const epp_s32 srcStep[3], epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height))
EPPAPI(epp_Status, eppi_YPbPr420_RGB_BT601_u8_P3C3, (const epp_u8* const pSrc[3], const epp_s32 srcStep[3], epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height))
EPPAPI(epp_Status, eppi_YPbPrVUYA_RGBA_BT601_u8_AC4, (const epp_u8* pSrc, epp_s32 srcStep, epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height))
EPPAPI(epp_Status, eppi_YPbPrYUYV_RGB_BT601_u8_C2C3, (const epp_u8* pSrc, epp_s32 srcStep, epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height))
EPPAPI(epp_Status, eppi_YPbPrNV12_RGB_BT601_u8_P2C3, (const epp_u8* const pSrc[2], const epp_s32 srcStep[2], epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height))
EPPAPI(epp_Status, eppi_YCbCr444_RGBs_BT601_u8_P3C3, (const epp_u8* const pSrc[3], const epp_s32 srcStep[3], epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height))
EPPAPI(epp_Status, eppi_YCbCr422_RGBs_BT601_u8_P3C3, (const epp_u8* const pSrc[3], const epp_s32 srcStep[3], epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height))
EPPAPI(epp_Status, eppi_YCbCr420_RGBs_BT601_u8_P3C3, (const epp_u8* const pSrc[3], const epp_s32 srcStep[3], epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height))
EPPAPI(epp_Status, eppi_YCbCrVUYA_RGBAs_BT601_u8_AC4, (const epp_u8* pSrc, epp_s32 srcStep, epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height))
EPPAPI(epp_Status, eppi_YCbCrYUYV_RGBs_BT601_u8_C2C3, (const epp_u8* pSrc, epp_s32 srcStep, epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height))
EPPAPI(epp_Status, eppi_YCbCrNV12_RGBs_BT601_u8_P2C3, (const epp_u8* const pSrc[2], const epp_s32 srcStep[2], epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height))

EPPAPI(epp_Status, eppi_YPbPr444_RGB_BT2020_u8_P3C3, (const epp_u8* const pSrc[3], const epp_s32 srcStep[3], epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height))
EPPAPI(epp_Status, eppi_YPbPr422_RGB_BT2020_u8_P3C3, (const epp_u8* const pSrc[3], const epp_s32 srcStep[3], epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height))
EPPAPI(epp_Status, eppi_YPbPr420_RGB_BT2020_u8_P3C3, (const epp_u8* const pSrc[3], const epp_s32 srcStep[3], epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height))
EPPAPI(epp_Status, eppi_YPbPrVUYA_RGBA_BT2020_u8_AC4, (const epp_u8* pSrc, epp_s32 srcStep, epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height))
EPPAPI(epp_Status, eppi_YPbPrYUYV_RGB_BT2020_u8_C2C3, (const epp_u8* pSrc, epp_s32 srcStep, epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height))
EPPAPI(epp_Status, eppi_YPbPrNV12_RGB_BT2020_u8_P2C3, (const epp_u8* const pSrc[2], const epp_s32 srcStep[2], epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height))
EPPAPI(epp_Status, eppi_RGB_YPbPr444_BT2020_u8_C3P3, (const epp_u8* pSrc, epp_s32 srcStep, epp_u8* const pDst[3], const epp_s32 dstStep[3], epp_size width, epp_size height))
EPPAPI(epp_Status, eppi_RGB_YPbPr422_BT2020_u8_C3P3, (const epp_u8* pSrc, epp_s32 srcStep, epp_u8* const pDst[3], const epp_s32 dstStep[3], epp_size width, epp_size height))
EPPAPI(epp_Status, eppi_RGB_YPbPr420_BT2020_u8_C3P3, (const epp_u8* pSrc, epp_s32 srcStep, epp_u8* const pDst[3], const epp_s32 dstStep[3], epp_size width, epp_size height))
EPPAPI(epp_Status, eppi_RGBA_YPbPrVUYA_BT2020_u8_AC4, (const epp_u8* pSrc, epp_s32 srcStep, epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height))
EPPAPI(epp_Status, eppi_RGB_YPbPrYUYV_BT2020_u8_C3C2, (const epp_u8* pSrc, epp_s32 srcStep, epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height))
EPPAPI(epp_Status, eppi_RGB_YPbPrNV12_BT2020_u8_C3P2, (const epp_u8* pSrc, epp_s32 srcStep, epp_u8* const pDst[2], const epp_s32 dstStep[2], epp_size width, epp_size height))


/*
//  Name:        eppi_ResizeGetBufferSize
//  Purpose:     Computes size of buffer for eppi_Resize
//  Context:
//  Returns:     epp_Status
//    epp_StsOK                    OK
//    epp_StsInterpolationModeErr  Wrong interpolation mode
//  Parameters:
//    numChannels    The number of channels in image.
//    srcWidth       The width of source image.
//    srcHeight      The height of source image.
//    dstWidth       The width of destination image.
//    dstHheight     The height of destination image.
//    interpolation  Interpolation mode.
//    pBufferSize    Pointer to the size of buffer.
//  Notes:
*/
EPPAPI(epp_Status, eppi_ResizeGetBufferSize, (epp_size numChannels, epp_size srcWidth, epp_size srcHeight, epp_size dstWidth, epp_size dstHeight, epp_InterpolationMode interpolation, epp_size* pBufferSize))


/*
//  Name:        eppi_Resize
//  Purpose:     Resizes image
//  Context:
//  Returns:     epp_Status
//    epp_StsOK                    OK
//    epp_StsInterpolationModeErr  Wrong interpolation mode
//  Parameters:
//    pSrc           Pointer to the source image (multichannel or planes)
//    srcStep        Step through the source image(s)
//    srcWidth       The width of source image.
//    srcHeight      The height of source image.
//    pDst           Pointer to the destination image (multichannel or planes)
//    dstStep        Step through the destination image(s)
//    dstWidth       The width of destination image.
//    dstHheight     The height of destination image.
//    interpolation  Interpolation mode.
//    pBuffer        Pointer to the external buffer.
//  Notes:
*/
EPPAPI(epp_Status, eppi_Resize_u8_C1, (const epp_u8* pSrc, epp_s32 srcStep, epp_size srcWidth, epp_size srcHeight, epp_u8* pDst, epp_s32 dstStep, epp_size dstWidth, epp_size dstHeight, epp_InterpolationMode interpolation, void* pBuffer))
EPPAPI(epp_Status, eppi_Resize_u8_C3, (const epp_u8* pSrc, epp_s32 srcStep, epp_size srcWidth, epp_size srcHeight, epp_u8* pDst, epp_s32 dstStep, epp_size dstWidth, epp_size dstHeight, epp_InterpolationMode interpolation, void* pBuffer))

//EPPAPI(epp_Status, eppi_Resize_u8f32_C1, (const epp_u8* pSrc, epp_s32 srcStep, epp_size srcWidth, epp_size srcHeight, epp_f32* pDst, epp_s32 dstStep, epp_size dstWidth, epp_size dstHeight, epp_InterpolationMode interpolation, void* pBuffer))


/*
//  Name:        eppi_Histogram_u8
//  Purpose:     Computes image histogram
//  Context:
//  Returns:     epp_Status
//    epp_StsOK  OK
//  Parameters:
//    pSrc       Pointer to the source image(s)
//    srcStep    Step through the source image(s)
//    pHist      Pointer to the destination histogram(s)
//    width      The width of images.
//    height     The height of images.
//  Notes:
*/
EPPAPI(epp_Status, eppi_Histogram_u8_C1, (const epp_u8* pSrc, epp_s32 srcStep, epp_u32 pHist[256], epp_size width, epp_size height))
EPPAPI(epp_Status, eppi_Histogram_u8_C3, (const epp_u8* pSrc, epp_s32 srcStep, epp_u32 pHist[3*256], epp_size width, epp_size height))


/*
//  Name:        eppi_CumulativeHistogram_u8_C1
//  Purpose:     Computes cumulative image histogram from normal histogram
//  Context:
//  Returns:     epp_Status
//    epp_StsOK  OK
//  Parameters:
//    pHist      Pointer to the source normal histogram
//    pHistC     Pointer to the destination cumulative histogram
//  Notes:
*/
EPPAPI(epp_Status, eppi_CumulativeHistogram_u8_C1, (const epp_u32 pHist[256], epp_u32 pHistC[256]))


/*
//  Name:        eppi_EqualizeHistogram_u8_C1
//  Purpose:     Computes equalized image histogram from normal histogram and LUT for transform
//  Context:
//  Returns:     epp_Status
//    epp_StsOK            OK
//    epp_StsDivByZeroErr  if all values in normal histogram are zero
//  Parameters:
//    pHist      Pointer to the source normal histogram
//    pHistE     Pointer to the destination equalized histogram (if it is not equal to NULL)
//    pLUT       Pointer to the destination lookup table for transform
//  Notes:
*/

EPPAPI(epp_Status, eppi_EqualizeHistogram_u8_C1, (const epp_u32 pHist[256], epp_u32 pHistE[256], epp_u8 pLUT[256]))


/*
//  Name:        eppi_LUT
//  Purpose:     Performs intensity transformation using lookup table(s)
//  Context:
//  Returns:     epp_Status
//    epp_StsOK  OK
//  Parameters:
//    pSrc       Pointer to the source image (multichannel or planes)
//    srcStep    Step through the source image(s)
//    pLUT       Pointer to lookup table(s)
//    pDst       Pointer to the destination image (multichannel or planes)
//    dstStep    Step through the destination image(s)
//    width      The width of images.
//    height     The height of images.
//  Notes:
*/

EPPAPI(epp_Status, eppi_LUT_u8_C1, (const epp_u8* pSrc, epp_s32 srcStep, const epp_u8 pLUT[256], epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height))
EPPAPI(epp_Status, eppi_LUT_u8_C3, (const epp_u8* pSrc, epp_s32 srcStep, const epp_u8 pLUT[3*256], epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height))


/*
//  Name:        eppi_MulCAddC
//  Purpose:     Multiplicates image pixels by value and adds another value
//  Context:
//  Returns:     epp_Status
//    epp_StsOK  OK
//  Parameters:
//    pSrc       Pointer to the source image (multichannel or planes)
//    srcStep    Step through the source image(s)
//    vMul       Value(s) to multiplicate
//    vAdd       Value(s) to add
//    pDst       Pointer to the destination image (multichannel or planes)
//    dstStep    Step through the destination image(s)
//    width      The width of images.
//    height     The height of images.
//  Notes:
*/
EPPAPI(epp_Status, eppi_MulCAddC_u8f32_C1, (const epp_u8* pSrc, epp_s32 srcStep, epp_f32 vMul, epp_f32 vAdd, epp_f32* pDst, epp_s32 dstStep, epp_size width, epp_size height))
EPPAPI(epp_Status, eppi_MulCAddC_u8f32_C3, (const epp_u8* pSrc, epp_s32 srcStep, const epp_f32 vMul[3], const epp_f32 vAdd[3], epp_f32* pDst, epp_s32 dstStep, epp_size width, epp_size height))
EPPAPI(epp_Status, eppi_MulCAddC_u8f32_C3P3, (const epp_u8* pSrc, epp_s32 srcStep, const epp_f32 vMul[3], const epp_f32 vAdd[3], epp_f32* const pDst[3], const epp_s32 dstStep[3], epp_size width, epp_size height))


/*
//  Name:        eppi_AddC
//  Purpose:     Adds value to image pixels
//  Context:
//  Returns:     epp_Status
//    epp_StsOK  OK
//  Parameters:
//    pSrc       Pointer to the source image (multichannel or planes)
//    srcStep    Step through the source image(s)
//    vAdd       Value(s) to add
//    pDst       Pointer to the destination image (multichannel or planes)
//    dstStep    Step through the destination image(s)
//    width      The width of images.
//    height     The height of images.
//  Notes:
*/
EPPAPI(epp_Status, eppi_AddC_u8_C1S, (const epp_u8* pSrc, epp_s32 srcStep, epp_u8 vAdd, epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height))
EPPAPI(epp_Status, eppi_AddC_u8_C3S, (const epp_u8* pSrc, epp_s32 srcStep, const epp_u8 vAdd[3], epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height))


/*
//  Name:        eppi_SubC
//  Purpose:     Subtracts value from image pixels
//  Context:
//  Returns:     epp_Status
//    epp_StsOK  OK
//  Parameters:
//    pSrc       Pointer to the source image (multichannel or planes)
//    srcStep    Step through the source image(s)
//    vSub       Value(s) to subtract
//    pDst       Pointer to the destination image (multichannel or planes)
//    dstStep    Step through the destination image(s)
//    width      The width of images.
//    height     The height of images.
//  Notes:
*/
EPPAPI(epp_Status, eppi_SubC_u8_C1S, (const epp_u8* pSrc, epp_s32 srcStep, epp_u8 vSub, epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height))
EPPAPI(epp_Status, eppi_SubC_u8_C3S, (const epp_u8* pSrc, epp_s32 srcStep, const epp_u8 vSub[3], epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height))


/*
//  Name:        eppi_Rotate
//  Purpose:     Rotates image by 90, 180, 270 degree counterclockwise
//  Context:
//  Returns:     epp_Status
//    epp_StsOK  OK
//  Parameters:
//    pSrc       Pointer to the source image (multichannel or planes)
//    srcStep    Step through the source image(s)
//    srcWidth   The width of source image.
//    srcHeight  The height of source image.
//    pDst       Pointer to the destination image (multichannel or planes)
//    dstStep    Step through the destination image(s)
//  Notes:
*/
EPPAPI(epp_Status, eppi_Rotate90_u8_C1, (const epp_u8* pSrc, epp_s32 srcStep, epp_size srcWidth, epp_size srcHeight, epp_u8* pDst, epp_s32 dstStep))
EPPAPI(epp_Status, eppi_Rotate90_u8_C3, (const epp_u8* pSrc, epp_s32 srcStep, epp_size srcWidth, epp_size srcHeight, epp_u8* pDst, epp_s32 dstStep))
EPPAPI(epp_Status, eppi_Rotate90_u8_C4, (const epp_u8* pSrc, epp_s32 srcStep, epp_size srcWidth, epp_size srcHeight, epp_u8* pDst, epp_s32 dstStep))
EPPAPI(epp_Status, eppi_Rotate180_u8_C1, (const epp_u8* pSrc, epp_s32 srcStep, epp_size srcWidth, epp_size srcHeight, epp_u8* pDst, epp_s32 dstStep))
EPPAPI(epp_Status, eppi_Rotate180_u8_C3, (const epp_u8* pSrc, epp_s32 srcStep, epp_size srcWidth, epp_size srcHeight, epp_u8* pDst, epp_s32 dstStep))
EPPAPI(epp_Status, eppi_Rotate180_u8_C4, (const epp_u8* pSrc, epp_s32 srcStep, epp_size srcWidth, epp_size srcHeight, epp_u8* pDst, epp_s32 dstStep))
EPPAPI(epp_Status, eppi_Rotate270_u8_C1, (const epp_u8* pSrc, epp_s32 srcStep, epp_size srcWidth, epp_size srcHeight, epp_u8* pDst, epp_s32 dstStep))
EPPAPI(epp_Status, eppi_Rotate270_u8_C3, (const epp_u8* pSrc, epp_s32 srcStep, epp_size srcWidth, epp_size srcHeight, epp_u8* pDst, epp_s32 dstStep))
EPPAPI(epp_Status, eppi_Rotate270_u8_C4, (const epp_u8* pSrc, epp_s32 srcStep, epp_size srcWidth, epp_size srcHeight, epp_u8* pDst, epp_s32 dstStep))


/*
//  Name:        eppi_Mirror
//  Purpose:     Mirrors image about horizontal or vertical axis, or both
//  Context:
//  Returns:     epp_Status
//    epp_StsOK  OK
//  Parameters:
//    pSrc       Pointer to the source image (multichannel or planes)
//    srcStep    Step through the source image(s)
//    srcWidth   The width of source image.
//    srcHeight  The height of source image.
//    pDst       Pointer to the destination image (multichannel or planes)
//    dstStep    Step through the destination image(s)
//  Notes:
*/
EPPINL(epp_Status, eppi_MirrorH_u8_C1, (const epp_u8* pSrc, epp_s32 srcStep, epp_size srcWidth, epp_size srcHeight, epp_u8* pDst, epp_s32 dstStep))
{
    return eppi_Copy_u8_C1(pSrc, srcStep, pDst + (srcHeight - 1) * dstStep, -dstStep, srcWidth, srcHeight);
}
EPPINL(epp_Status, eppi_MirrorH_u8_C3, (const epp_u8* pSrc, epp_s32 srcStep, epp_size srcWidth, epp_size srcHeight, epp_u8* pDst, epp_s32 dstStep))
{
    return eppi_Copy_u8_C3(pSrc, srcStep, pDst + (srcHeight - 1) * dstStep, -dstStep, srcWidth, srcHeight);
}
EPPINL(epp_Status, eppi_MirrorH_u8_C4, (const epp_u8* pSrc, epp_s32 srcStep, epp_size srcWidth, epp_size srcHeight, epp_u8* pDst, epp_s32 dstStep))
{
    return eppi_Copy_u8_C4(pSrc, srcStep, pDst + (srcHeight - 1) * dstStep, -dstStep, srcWidth, srcHeight);
}
EPPINL(epp_Status, eppi_MirrorV_u8_C1, (const epp_u8* pSrc, epp_s32 srcStep, epp_size srcWidth, epp_size srcHeight, epp_u8* pDst, epp_s32 dstStep))
{
    return eppi_Rotate180_u8_C1(pSrc, srcStep, srcWidth, srcHeight, pDst + (srcHeight - 1) * dstStep, -dstStep);
}
EPPINL(epp_Status, eppi_MirrorV_u8_C3, (const epp_u8* pSrc, epp_s32 srcStep, epp_size srcWidth, epp_size srcHeight, epp_u8* pDst, epp_s32 dstStep))
{
    return eppi_Rotate180_u8_C3(pSrc, srcStep, srcWidth, srcHeight, pDst + (srcHeight - 1) * dstStep, -dstStep);
}
EPPINL(epp_Status, eppi_MirrorV_u8_C4, (const epp_u8* pSrc, epp_s32 srcStep, epp_size srcWidth, epp_size srcHeight, epp_u8* pDst, epp_s32 dstStep))
{
    return eppi_Rotate180_u8_C4(pSrc, srcStep, srcWidth, srcHeight, pDst + (srcHeight - 1) * dstStep, -dstStep);
}
EPPINL(epp_Status, eppi_MirrorHV_u8_C1, (const epp_u8* pSrc, epp_s32 srcStep, epp_size srcWidth, epp_size srcHeight, epp_u8* pDst, epp_s32 dstStep))
{
    return eppi_Rotate180_u8_C1(pSrc, srcStep, srcWidth, srcHeight, pDst, dstStep);
}
EPPINL(epp_Status, eppi_MirrorHV_u8_C3, (const epp_u8* pSrc, epp_s32 srcStep, epp_size srcWidth, epp_size srcHeight, epp_u8* pDst, epp_s32 dstStep))
{
    return eppi_Rotate180_u8_C3(pSrc, srcStep, srcWidth, srcHeight, pDst, dstStep);
}
EPPINL(epp_Status, eppi_MirrorHV_u8_C4, (const epp_u8* pSrc, epp_s32 srcStep, epp_size srcWidth, epp_size srcHeight, epp_u8* pDst, epp_s32 dstStep))
{
    return eppi_Rotate180_u8_C4(pSrc, srcStep, srcWidth, srcHeight, pDst, dstStep);
}


/*
//  Name:        eppi_Transpose
//  Purpose:     Transposes image
//  Context:
//  Returns:     epp_Status
//    epp_StsOK  OK
//  Parameters:
//    pSrc       Pointer to the source image (multichannel or planes)
//    srcStep    Step through the source image(s)
//    srcWidth   The width of source image.
//    srcHeight  The height of source image.
//    pDst       Pointer to the destination image (multichannel or planes)
//    dstStep    Step through the destination image(s)
//  Notes:
*/
EPPINL(epp_Status, eppi_Transpose_u8_C1, (const epp_u8* pSrc, epp_s32 srcStep, epp_size srcWidth, epp_size srcHeight, epp_u8* pDst, epp_s32 dstStep))
{
    return eppi_Rotate90_u8_C1(pSrc, srcStep, srcWidth, srcHeight, pDst + (srcHeight - 1) * dstStep, -dstStep);
}
EPPINL(epp_Status, eppi_Transpose_u8_C3, (const epp_u8* pSrc, epp_s32 srcStep, epp_size srcWidth, epp_size srcHeight, epp_u8* pDst, epp_s32 dstStep))
{
    return eppi_Rotate90_u8_C3(pSrc, srcStep, srcWidth, srcHeight, pDst + (srcHeight - 1) * dstStep, -dstStep);
}
EPPINL(epp_Status, eppi_Transpose_u8_C4, (const epp_u8* pSrc, epp_s32 srcStep, epp_size srcWidth, epp_size srcHeight, epp_u8* pDst, epp_s32 dstStep))
{
    return eppi_Rotate90_u8_C4(pSrc, srcStep, srcWidth, srcHeight, pDst + (srcHeight - 1) * dstStep, -dstStep);
}


#ifdef __cplusplus
}
#endif
